const _Get = require('lodash.get');

async function handleMessage(data) {
    /**
     * Object {
     *     [project_uid]: {
     *         nodes: Array({
     *             mac_address: string,
     *             trackable_name: string,
     *             battery: number, (%)
     *         })
     *         subscribers: Array()
     *         notifications: Array()
     *         smsList: Array<string>
     *         emailList: Array<string>
     *     }
     * }
     */
    const sendingData = data.nodes;

    data.subscribers.forEach((subscriber) => {
        if (sendingData[subscriber.project_uid]) {
            subscriber.notifications.forEach((notification_uid) => {
                const notification = data.notifications.find(x => x.uid === notification_uid);
                if (notification) {
                    const notificationEmail = _Get(notification, 'types.email');
                    const subscriberEmail = _Get(subscriber, 'addresses.email');
                    const subscriberName = _Get(subscriber, 'name');

                    const notificationPhone = _Get(notification, 'types.phone');
                    const subscriberPhone = _Get(subscriber, 'addresses.phone');

                    if (notificationEmail && subscriberEmail) {
                        sendingData[subscriber.project_uid].emailList.push({ email: subscriberEmail, name: subscriberName });
                    }
                    if (notificationPhone && subscriberPhone) {
                        sendingData[subscriber.project_uid].smsList.push(subscriberPhone);
                    }
                }
            });
        }
    });
    process.send(JSON.stringify(sendingData));
    process.exit(1);
}

process.on('message', handleMessage);
